
print.dma <- function(x, ...)
  {
   cat("Model: ")
   cat(colnames(x$y))
   cat(" ~ ")
   cat(paste(colnames(x$models),collapse=" + "))
   cat("\n")
   cat("\n")
   print(x$parameters,quote=FALSE)
   cat("\n")
   err <- rbind(x$RMSE,x$MAE)
   colnames(err) <- c("model")
   err <- cbind(err,x$benchmarks)
   print(round(err,digits=4))
   cat("\n")
   cat("observations: ")
   cat(length(x$y.hat))
   cat("\n")
   cat("models: ")
   cat(nrow(x$models))
   cat("\n")
   cat("variables (incl. constant): ")
   cat(ncol(x$models))
   cat("\n")
  }
